==> calendar-v1.7.20.zip: calendar/messages/vi/base.php <==
<?php

return [
    '<strong>Add</strong> profile calendar' => '<strong>Thêm</strong> lịch riêng',
    '<strong>Choose</strong> target calendar' => '<strong>Chọn</strong> lịch mục tiêu',
    '<strong>Reminder</strong> settings' => 'Thiết lập <strong>Nhắc nhở</strong>',
    'Adds a calendar for private or public events to your profile and main menu.' => 'Thêm lịch cho sự kiện riêng tư hoặc công cộng vào Trang hồ sơ và Menu chính của bạn.',
    'Adds an event calendar to this space.' => 'Thêm lịch sự kiện vào diên đàn này',
    'After (occurrences)' => 'Sau (sự xảy ra)',
    'All Day' => 'Cả ngày',
    'Allows the user to create new calendar entries' => 'Cho phép người dùng tạo lịch mới',
    'Allows the user to edit/delete existing calendar entries' => 'Cho phép người dùng chỉnh sửa/xóa lịch hiện có',
    'Attending' => 'Sẽ tham gia',
    'Birthday' => 'Sinh nhật',
    'Calendar' => 'Lịch',
    'Cancel Event' => 'Hủy sự kiện',
    'Create entry' => 'Tạo lịch mới',
    'Custom reminder' => 'Tùy chỉnh nhắc nhở',
    'Day' => 'Ngày',
    'Days' => 'Những ngày',
    'Default reminder settings' => 'Thiết lập nhắc nhở mặc định',
    'Delete all events' => 'Xóa mọi sự kiện',
    'Deleted' => 'Đã xóa',
    'Description' => 'Mô tả',
    'Do you want to install this module on your profile?' => 'Bạn có muốn cài đặt module này vào trang cá nhân?',
    'Edit' => 'Chỉnh sửa',
    'Edit all events' => 'Sửa mọi sự kiện',
    'Edit this and following events' => 'Sửa sự kiện này và các sự kiện đang theo dõi',
    'Edit this event' => 'Sửa sự kiện này',
    'Email' => 'Email',
    'Enable' => 'Kích hoạt',
    'End' => 'Kết thúc',
    'End Date' => 'Ngày kết thúc',
    'End Time' => 'Giờ kết thúc',
    'End time must be after start time!' => 'Ngày kết thúc phải sau ngày bắt đầu!',
    'Event' => 'Sự kiện',
    'Event Type' => 'Loại sự kiện',
    'Event Types' => 'Loại sự kiện',
    'Event not found!' => 'Không tìm thấy sự kiện!',
    'Files' => 'Files',
    'Friday' => 'Thứ sáu',
    'Here you can configure default settings for all calendar events.' => 'ở đây bạn có thể thiết lập cấu hình mặc định cho mọi lịch sự kiện',
    'Here you can configure global default reminders. These settings can be overwritten on space/profile level.' => 'Ở đây bạn có thể cấu hình nhắc nhở mặc định chung trên hệ thống. Những cấu hình này có thể bị ghi đè ở mức diễn đàn/trang cá nhân.',
    'Here you can configure the default reminder settings for this event. Users are able to overwrite these settings by means of the
        <strong>Set reminder</strong> link.' => 'ở đây bạn có thể thiết lập các cấu hình nhắc nhở tự động cho sự kiện này. Người dùng có thể ghi đè các cấu hình này bằng liên kết <strong>Thiết lập nhắc nhở</strong>',
    'Hour' => 'Giờ',
    'I\'m attending' => 'Tôi đang tham gia',
    'ID' => 'ID',
    'In order to add events to your profile, you have to enable the calendar module first.' => 'Để thêm sự kiện vào trang hồ sơ của bạn, bạn phải kích hoạt module Lịch trước.',
    'Interested' => 'Yêu thích.',
    'Invalid date or time format!' => 'Định dạng ngày giờ không hợp lệ',
    'Invalid day of month given' => 'Ngày của tháng không hợp lệ',
    'Invalid event type id selected.' => 'Sai ID loại sự kiện',
    'Invalid frequency given' => 'Tần suất không hợp lệ',
    'Invalid interval given' => 'Khoảng thời gian không hợp lệ',
    'Invalid week day selection' => 'Thứ lựa chọn không hợp lệ',
    'Invite' => 'Mời',
    'List' => 'Danh sách',
    'Location' => 'Địa điểm',
    'Manage entries' => 'Quản lý lịch',
    'Maximum number of participants' => 'Số người tham dự tối đa',
    'Monday' => 'Thứ hai',
    'Month' => 'Tháng',
    'Monthly on day {dayOfMonth}' => 'Hàng tháng vào ngày {dayOfMonth}',
    'Monthly on the {position} {dayOfWeek}' => 'Hàng tháng vào ngày {position} {dayOfWeek}',
    'Months' => 'Tháng',
    'Never' => 'Không bao giờ',
    'Next' => 'Tiếp theo',
    'No reminder' => 'Không nhắc',
    'On date' => 'Vào ngày',
    'Participants' => 'Người tham gia',
    'Profile Calendar' => 'Lịch hồ sơ cá nhân',
    'Public' => 'Công cộng',
    'Reopen Event' => 'Mở lại sự kiện',
    'Repeat every' => 'Lặp lại mỗi',
    'Saturday' => 'Thứ bảy',
    'Set reminder' => 'Thiết lập nhắc nhở',
    'Sorting' => 'Sắp xếp',
    'Start Date' => 'Ngày bắt đầu',
    'Start Time' => 'Thời gian bắt đầu',
    'Sunday' => 'Chủ nhật',
    'This event does not support recurrent events' => 'Sự kiện này không hỗ trợ lặp lại',
    'Thursday' => 'Thứ năm',
    'Time Zone' => 'Múi giờ',
    'Title' => 'Tiêu đề',
    'Today' => 'Hôm nay',
    'Tuesday' => 'Thứ ba',
    'Upcoming {type}' => 'Sắp diễn ra {type}',
    'Upcoming {type}: {title}' => 'Sắp diễn ra {type}: {title}',
    'Use default reminder' => 'Dùng nhắc nhở mặc định',
    'Wednesday' => 'Thứ tư',
    'Week' => 'Tuần',
    'Weeks' => 'Các tuần',
    'Year' => 'Năm',
    'Years' => 'Các năm',
    'You don\'t have permission to delete this event!' => 'Bạn không có quyền xóa sự kiện này!',
    'You have an <strong>{type}</strong> coming up' => 'Bạn có một <strong>{type}</strong> sắp diễn ra',
    'You have an <strong>{type}</strong> coming up: {title}' => 'Bạn có một <strong>{type}</strong> sắp diễn ra: {title}',
    'Your reminder settings for event: <strong>\'{title}\'</strong>' => 'Cấu hình nhắc nhở cho sự kiện của bạn: <strong>\'{title}\'</strong>',
    'canceled' => 'đã hủy',
    'disabled' => 'tàn tật',
    'first' => 'Nhứ nhất',
    'forth' => 'Thứ tư',
    'on weekdays' => 'vào các ngày trong tuần',
    'second' => 'Thứ hai',
    'third' => 'Thứ ba',
    '{displayName} Birthday' => 'Sinh nhật {displayName}',
    '{displayName} added you to the event "{contentTitle}" in the space {spaceName}, starting at {time}.' => '{displayName} vừa mới thêm bạn vào sự kiện "{contentTitle}" trong diễn đàn {spaceName} bắt đầu từ {time}.',
    '{displayName} added you to the event "{contentTitle}".' => '{displayName} vừa thêm bạn vào sự kiện "{contentTitle}".',
    'Add all Space members with status {status}' => '',
    'Add participants...' => '',
    'Added: {users}' => '',
    'Additional Information for participants' => '',
    'Allow option \'Decline\'' => '',
    'Allow option \'Undecided\'' => '',
    'Before a target calendar can be selected, the module must be activated in at least one Space.' => '',
    'CalDAV' => '',
    'Calendar event' => '',
    'Calendar event content ID' => '',
    'Calendar events' => '',
    'Cannot remove the participant!' => '',
    'Display events within the next X days' => '',
    'Download ICS' => '',
    'Edit Event' => '',
    'Enable Reminder' => '',
    'Event could not be deleted!' => '',
    'Event has been be deleted!' => '',
    'Export as {type}' => '',
    'Filter by types' => '',
    'From Newest to Oldest' => '',
    'From Oldest to Newest' => '',
    'Include Organizer and Participant Info in Exports' => '',
    'Invited: {users}' => '',
    'JWT Key' => '',
    'JWT Token Expiration' => '',
    'Leave empty to list all events. Enter 0 to display only today\'s events.' => '',
    'Minute' => '',
    'Mode' => '',
    'No new participants were added.' => '',
    'No new participants were invited.' => '',
    'Notify participants about changes' => '',
    'Participant removed.' => '',
    'Participation Status' => '',
    'Please select new participants.' => '',
    'Private events are only visible to you and, if the friendship system is activated, to your friends.' => '',
    'Recurring' => '',
    'Select calendar...' => '',
    'Select space...' => '',
    'Show past events' => '',
    'Status cannot be updated.' => '',
    'Status updated.' => '',
    'The event has already ended.' => '',
    'Used for secure iCal feed URL generation and CalDAV authentication. Changing this key will revoke all existing iCal URLs and CalDAV logins. If empty, a random key is generated automatically.' => '',
    'User birthdays' => '',
    'When enabled, calendar exports (ics, iCal, CalDAV) will include the organizer\'s and participant\'s names and email addresses. Disable to exclude this information for increased privacy.' => '',
    'You cannot invite participants!' => '',
    'You have been registered for the event "{contentTitle}" in {spaceName}, starting at {time}' => '',
    'You have been registered for the event "{contentTitle}", starting at {time}.' => '',
    'You have been registered for the event "{contentTitle}".' => '',
    'global' => '',
    'iCal' => '',
    'in seconds. 0 for no JWT token expiration.' => '',
    'last' => '',
    '{displayName} invited you to the event "{contentTitle}" in the space {spaceName}, starting at {time}.' => '',
    '{displayName} invited you to the event "{contentTitle}".' => '',
    '{name} Calendar' => '',
];

==> calendar-v1.8.3.zip: calendar/messages/vi/base.php <==
<?php

return [
    '<strong>Add</strong> profile calendar' => '<strong>Thêm</strong> lịch riêng',
    '<strong>Choose</strong> target calendar' => '<strong>Chọn</strong> lịch mục tiêu',
    '<strong>Reminder</strong> settings' => 'Thiết lập <strong>Nhắc nhở</strong>',
    'Adds a calendar for private or public events to your profile and main menu.' => 'Thêm lịch cho sự kiện riêng tư hoặc công cộng vào Trang hồ sơ và Menu chính của bạn.',
    'Adds an event calendar to this space.' => 'Thêm lịch sự kiện vào diên đàn này',
    'After (occurrences)' => 'Sau (sự xảy ra)',
    'All Day' => 'Cả ngày',
    'Allows the user to create new calendar entries' => 'Cho phép người dùng tạo lịch mới',
    'Allows the user to edit/delete existing calendar entries' => 'Cho phép người dùng chỉnh sửa/xóa lịch hiện có',
    'Attending' => 'Sẽ tham gia',
    'Birthday' => 'Sinh nhật',
    'Calendar' => 'Lịch',
    'Cancel Event' => 'Hủy sự kiện',
    'Create entry' => 'Tạo lịch mới',
    'Custom reminder' => 'Tùy chỉnh nhắc nhở',
    'Day' => 'Ngày',
    'Days' => 'Những ngày',
    'Default reminder settings' => 'Thiết lập nhắc nhở mặc định',
    'Delete all events' => 'Xóa mọi sự kiện',
    'Deleted' => 'Đã xóa',
    'Description' => 'Mô tả',
    'Do you want to install this module on your profile?' => 'Bạn có muốn cài đặt module này vào trang cá nhân?',
    'Edit' => 'Chỉnh sửa',
    'Edit all events' => 'Sửa mọi sự kiện',
    'Edit this and following events' => 'Sửa sự kiện này và các sự kiện đang theo dõi',
    'Edit this event' => 'Sửa sự kiện này',
    'Email' => 'Email',
    'Enable' => 'Kích hoạt',
    'End' => 'Kết thúc',
    'End Date' => 'Ngày kết thúc',
    'End Time' => 'Giờ kết thúc',
    'End time must be after start time!' => 'Ngày kết thúc phải sau ngày bắt đầu!',
    'Event' => 'Sự kiện',
    'Event Type' => 'Loại sự kiện',
    'Event Types' => 'Loại sự kiện',
    'Event not found!' => 'Không tìm thấy sự kiện!',
    'Files' => 'Files',
    'Friday' => 'Thứ sáu',
    'Here you can configure default settings for all calendar events.' => 'ở đây bạn có thể thiết lập cấu hình mặc định cho mọi lịch sự kiện',
    'Here you can configure global default reminders. These settings can be overwritten on space/profile level.' => 'Ở đây bạn có thể cấu hình nhắc nhở mặc định chung trên hệ thống. Những cấu hình này có thể bị ghi đè ở mức diễn đàn/trang cá nhân.',
    'Hour' => 'Giờ',
    'I\'m attending' => 'Tôi đang tham gia',
    'ID' => 'ID',
    'In order to add events to your profile, you have to enable the calendar module first.' => 'Để thêm sự kiện vào trang hồ sơ của bạn, bạn phải kích hoạt module Lịch trước.',
    'Interested' => 'Yêu thích.',
    'Invalid date or time format!' => 'Định dạng ngày giờ không hợp lệ',
    'Invalid day of month given' => 'Ngày của tháng không hợp lệ',
    'Invalid event type id selected.' => 'Sai ID loại sự kiện',
    'Invalid frequency given' => 'Tần suất không hợp lệ',
    'Invalid interval given' => 'Khoảng thời gian không hợp lệ',
    'Invalid week day selection' => 'Thứ lựa chọn không hợp lệ',
    'Invite' => 'Mời',
    'List' => 'Danh sách',
    'Location' => 'Địa điểm',
    'Manage entries' => 'Quản lý lịch',
    'Maximum number of participants' => 'Số người tham dự tối đa',
    'Monday' => 'Thứ hai',
    'Month' => 'Tháng',
    'Monthly on day {dayOfMonth}' => 'Hàng tháng vào ngày {dayOfMonth}',
    'Monthly on the {position} {dayOfWeek}' => 'Hàng tháng vào ngày {position} {dayOfWeek}',
    'Months' => 'Tháng',
    'Never' => 'Không bao giờ',
    'Next' => 'Tiếp theo',
    'No reminder' => 'Không nhắc',
    'On date' => 'Vào ngày',
    'Participants' => 'Người tham gia',
    'Profile Calendar' => 'Lịch hồ sơ cá nhân',
    'Public' => 'Công cộng',
    'Reopen Event' => 'Mở lại sự kiện',
    'Repeat every' => 'Lặp lại mỗi',
    'Saturday' => 'Thứ bảy',
    'Set reminder' => 'Thiết lập nhắc nhở',
    'Sorting' => 'Sắp xếp',
    'Start Date' => 'Ngày bắt đầu',
    'Start Time' => 'Thời gian bắt đầu',
    'Sunday' => 'Chủ nhật',
    'This event does not support recurrent events' => 'Sự kiện này không hỗ trợ lặp lại',
    'Thursday' => 'Thứ năm',
    'Time Zone' => 'Múi giờ',
    'Title' => 'Tiêu đề',
    'Today' => 'Hôm nay',
    'Tuesday' => 'Thứ ba',
    'Upcoming {type}' => 'Sắp diễn ra {type}',
    'Upcoming {type}: {title}' => 'Sắp diễn ra {type}: {title}',
    'Use default reminder' => 'Dùng nhắc nhở mặc định',
    'Wednesday' => 'Thứ tư',
    'Week' => 'Tuần',
    'Weeks' => 'Các tuần',
    'Year' => 'Năm',
    'Years' => 'Các năm',
    'You don\'t have permission to delete this event!' => 'Bạn không có quyền xóa sự kiện này!',
    'You have an <strong>{type}</strong> coming up' => 'Bạn có một <strong>{type}</strong> sắp diễn ra',
    'You have an <strong>{type}</strong> coming up: {title}' => 'Bạn có một <strong>{type}</strong> sắp diễn ra: {title}',
    'Your reminder settings for event: <strong>\'{title}\'</strong>' => 'Cấu hình nhắc nhở cho sự kiện của bạn: <strong>\'{title}\'</strong>',
    'canceled' => 'đã hủy',
    'disabled' => 'tàn tật',
    'first' => 'Nhứ nhất',
    'forth' => 'Thứ tư',
    'on weekdays' => 'vào các ngày trong tuần',
    'second' => 'Thứ hai',
    'third' => 'Thứ ba',
    '{displayName} Birthday' => 'Sinh nhật {displayName}',
    '{displayName} added you to the event "{contentTitle}" in the space {spaceName}, starting at {time}.' => '{displayName} vừa mới thêm bạn vào sự kiện "{contentTitle}" trong diễn đàn {spaceName} bắt đầu từ {time}.',
    '{displayName} added you to the event "{contentTitle}".' => '{displayName} vừa thêm bạn vào sự kiện "{contentTitle}".',
    'Add all Space members with status {status}' => '',
    'Add participants...' => '',
    'Added: {users}' => '',
    'Additional Information for participants' => '',
    'Allow option \'Decline\'' => '',
    'Allow option \'Undecided\'' => '',
    'Before a target calendar can be selected, the module must be activated in at least one Space.' => '',
    'CalDAV' => '',
    'Calendar event' => '',
    'Calendar event content ID' => '',
    'Calendar events' => '',
    'Cannot remove the participant!' => '',
    'Display events within the next X days' => '',
    'Download ICS' => '',
    'Edit Event' => '',
    'Enable Reminder' => '',
    'Event could not be deleted!' => '',
    'Event has been be deleted!' => '',
    'Export as {type}' => '',
    'Filter' => '',
    'Filter by types' => '',
    'From Newest to Oldest' => '',
    'From Oldest to Newest' => '',
    'Here you can configure the default reminder settings for this event. Users are able to overwrite these settings by means of the
    <strong>Set reminder</strong> link.' => '',
    'Include Organizer and Participant Info in Exports' => '',
    'Invited: {users}' => '',
    'JWT Key' => '',
    'JWT Token Expiration' => '',
    'Leave empty to list all events. Enter 0 to display only today\'s events.' => '',
    'Minute' => '',
    'Mode' => '',
    'No new participants were added.' => '',
    'No new participants were invited.' => '',
    'Notify participants about changes' => '',
    'Participant removed.' => '',
    'Participation Status' => '',
    'Please select new participants.' => '',
    'Private events are only visible to you and, if the friendship system is activated, to your friends.' => '',
    'Recurring' => '',
    'Select calendar...' => '',
    'Select space...' => '',
    'Show past events' => '',
    'Status cannot be updated.' => '',
    'Status updated.' => '',
    'The event has already ended.' => '',
    'Used for secure iCal feed URL generation and CalDAV authentication. Changing this key will revoke all existing iCal URLs and CalDAV logins. If empty, a random key is generated automatically.' => '',
    'User birthdays' => '',
    'When enabled, calendar exports (ics, iCal, CalDAV) will include the organizer\'s and participant\'s names and email addresses. Disable to exclude this information for increased privacy.' => '',
    'You cannot invite participants!' => '',
    'You have been registered for the event "{contentTitle}" in {spaceName}, starting at {time}' => '',
    'You have been registered for the event "{contentTitle}", starting at {time}.' => '',
    'You have been registered for the event "{contentTitle}".' => '',
    'global' => '',
    'iCal' => '',
    'in seconds. 0 for no JWT token expiration.' => '',
    'last' => '',
    '{displayName} invited you to the event "{contentTitle}" in the space {spaceName}, starting at {time}.' => '',
    '{displayName} invited you to the event "{contentTitle}".' => '',
    '{name} Calendar' => '',
];
